Method: Redstruct::Lock#expiry

Defined in:
lib/redstruct/lock.rb

#expiryFloat, Integer (readonly)

Returns the expiry of the underlying redis structure in seconds.

Returns:

  • (Float, Integer)

    the expiry of the underlying redis structure in seconds



29
30
31
# File 'lib/redstruct/lock.rb', line 29

def expiry
  @expiry
end